// Copyright (c) 2024 Yuki Kimoto
// MIT License

#include "spvm_native.h"



static const char* FILE_NAME = "Native/Constant.c";

int32_t SPVM__Native__Constant__foo(SPVM_ENV* env, SPVM_VALUE* stack) {
  
  return 0;
}


